import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range(['#B51B20','#e8e55a']);

const radiusScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range(['50','30']);

const xPosition = (d, i) => i * 120 + 60

/* 

svg.selectAll('circle') makes an empty selection because there are no circles 
prior to it being invoked.

Now we need to give it an array of data for the join
.data(fruits)

.append('circle') will append a circle to any data point that doesn't have a circle. 


*/
export const fruitBowl = (selection, props) =>{
  
  const { fruits, height } = props;
  
  //data join
  const circles = selection.selectAll('circle').data(fruits, d => { return d.id });
  circles
    .enter().append('circle')
  		.attr('cx', xPosition)
      .attr('cy', height/2)
  		.attr('r', 0)
  	.merge(circles)
      .attr('fill', (d)  => colorScale(d.type))
  	.transition().duration(1000)
      .attr('cx', xPosition)
			.attr('r', (d) => radiusScale(d.type));
  
  circles.exit()
    	.transition().duration(1000)
      .attr('r', 0)
    .remove();
  

}